- enrollment_dates
date vector with one entry per participants.
- by
factor or character vector with sites, has to have the same length as enrollment dates.
If not NA, a list with an accrual data frame for each site is generated.
- start_date
date when recruitment started. Single date (used for all sites in by),
named date vector (with length and names corresponding to the levels of by),
"common" (first date overall) or "site" (first date for each site, default).
- current_date
date of the data export or database freeze.
Single date, named date vector (with length and names corresponding to the levels of by),
"common" (last date overall, default) or "site" (first date for each site).
- overall
logical indicates that accrual_df contains a summary with all sites (only if by is not NA).
- name_overall
name of the summary with all sites (if by is not NA and overall==TRUE).
- pos_overall
overall as last or first element of the list (if by is not NA and overall==TRUE).
- force_start0
logical, adds an extra 0 line to the accrual data frame in cases
where a start date is given and corresponds to the earliest enrollment date.