Learn R Programming

accrualPlot (version 1.0.7)

accrual_time_unit: accrual_time_unit

Description

Generates summary of recruitment per time unit

Usage

accrual_time_unit(accrual_df, unit = c("month", "year", "week", "day"))

Value

Returns a data frame with the number of patients accrued for each time unit.

Arguments

accrual_df

accrual data frame produced by accrual_create_df with by=NA.

unit

time unit for which the bars should be plotted, one of "month", "year", "week" or "day".

Examples

Run this code
# \donttest{
data(accrualdemo)
accrual_df<-accrual_create_df(accrualdemo$date)
accrual_time_unit(accrual_df,"week")
accrual_time_unit(accrual_df,"day")
# }

Run the code above in your browser using DataLab