powered by
Generates summary of recruitment per time unit
accrual_time_unit(accrual_df, unit = c("month", "year", "week", "day"))
Returns a data frame with the number of patients accrued for each time unit.
accrual data frame produced by accrual_create_df with by=NA.
accrual_create_df
time unit for which the bars should be plotted, one of "month", "year", "week" or "day".
"month"
"year"
"week"
"day"
# \donttest{ data(accrualdemo) accrual_df<-accrual_create_df(accrualdemo$date) accrual_time_unit(accrual_df,"week") accrual_time_unit(accrual_df,"day") # }
Run the code above in your browser using DataLab